@@ -20,6 +20,8 @@ from oslo_serialization import jsonutils
 import webob
 import webob.dec
 
+from sahara.api import microversion as mv
+
 
 class VersionResponseMiddlewareV1(base.Middleware):
 
@@ -30,7 +32,7 @@ class VersionResponseMiddlewareV1(base.Middleware):
         if re.match(r"^/*$", path):
             response = webob.Response(request=req, status=300,
                                       content_type="application/json")
-            response.body = jsonutils.dumps(self._get_versions(req))
+            response.body = jsonutils.dump_as_bytes(self._get_versions(req))
             return response
         else:
             return self.application
@@ -64,10 +66,13 @@ class VersionResponseMiddlewareV2(VersionResponseMiddlewareV1):
         version_response = (
             super(VersionResponseMiddlewareV2, self)._get_versions(req)
         )
+        version_response["versions"][1]["status"] = "SUPPORTED"  # v1.1
         version_response["versions"].append(
             {"id": "v2",
-             "status": "EXPERIMENTAL",
-             "links": self._get_links("2", req)
+             "status": "CURRENT",
+             "links": self._get_links("2", req),
+             "min_version": mv.MIN_API_VERSION,
+             "max_version": mv.MAX_API_VERSION
              }
         )
         return version_response
