@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright (c) 2013 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,9 +19,6 @@ patches.patch_all()
 import os
 import sys
 
-import oslo_i18n
-
-
 # If ../sahara/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
 possible_topdir = os.path.normpath(os.path.join(os.path.abspath(sys.argv[0]),
@@ -35,13 +30,6 @@ if os.path.exists(os.path.join(possible_topdir,
     sys.path.insert(0, possible_topdir)
 
 
-# NOTE(slukjanov): i18n.enable_lazy() must be called before
-#                  sahara.utils.i18n._() is called to ensure it has the desired
-#                  lazy lookup behavior.
-oslo_i18n.enable_lazy()
-
-
-from sahara.api import acl
 import sahara.main as server
 from sahara.service import ops
 
@@ -49,12 +37,12 @@ from sahara.service import ops
 def main():
     server.setup_common(possible_topdir, 'engine')
 
-    # NOTE(apavlov): acl.wrap is called here to set up auth_uri value
-    # in context by using keystone functionality (mostly to avoid
-    # code duplication).
-    acl.wrap(None)
-
     server.setup_sahara_engine()
+    server.setup_sahara_api('distributed')
 
     ops_server = ops.OpsServer()
-    ops_server.start()
+    launcher = server.get_process_launcher()
+    service = ops_server.get_service()
+    launcher.launch_service(service)
+    service.start()
+    launcher.wait()
