@@ -103,6 +103,20 @@ dns_opts = [
                      "This is required if 'use_designate' is True")
 ]
 
+accessible_ip_opts = [
+    cfg.IPOpt('identity_ip_accessible',
+              default=None,
+              help='IP address of Keystone endpoint, accessible by tenant'
+                   ' machines. If not set, the results of the DNS lookup'
+                   ' performed where Sahara services are running will be'
+                   ' used.'),
+    cfg.IPOpt('object_store_ip_accessible',
+              default=None,
+              help='IP address of Swift endpoint, accessible by tenant'
+                   ' machines. If not set, the results of the DNS lookup'
+                   ' performed where Sahara services are running will be'
+                   ' used.'),
+]
 
 CONF = cfg.CONF
 CONF.register_cli_opts(cli_opts)
@@ -110,6 +124,7 @@ CONF.register_opts(networking_opts)
 CONF.register_opts(edp_opts)
 CONF.register_opts(db_opts)
 CONF.register_opts(dns_opts)
+CONF.register_opts(accessible_ip_opts)
 
 log.register_options(CONF)
 
@@ -137,6 +152,7 @@ def list_opts():
     from sahara.service.edp import job_utils
     from sahara.service.heat import heat_engine
     from sahara.service.heat import templates
+    from sahara.service import ntp_service
     from sahara.service import periodic
     from sahara.swift import swift_helper
     from sahara.utils import cluster_progress_ops as cpo
@@ -158,6 +174,7 @@ def list_opts():
                          networking_opts,
                          dns_opts,
                          db_opts,
+                         accessible_ip_opts,
                          plugins_base.opts,
                          topology_helper.opts,
                          keystone.opts,
@@ -166,6 +183,7 @@ def list_opts():
                          job_utils.opts,
                          periodic.periodic_opts,
                          coordinator.coordinator_opts,
+                         ntp_service.ntp_opts,
                          proxy.opts,
                          cpo.event_log_opts,
                          base.opts,
