@@ -105,9 +105,9 @@ def create_multiple_clusters(values):
         cluster_dict['name'] = get_multiple_cluster_name(num_of_clusters,
                                                          cluster_name,
                                                          counter + 1)
-        cluster = _cluster_create(cluster_dict, plugin)
+        cluster = _cluster_create(cluster_dict, plugin).to_wrapped_dict()
 
-        clusters.append(cluster.id)
+        clusters.append(cluster)
 
     clusters_dict = {'clusters': clusters}
     return clusters_dict
@@ -126,8 +126,8 @@ def _cluster_create(values, plugin):
         plugin.recommend_configs(cluster)
         cluster = c_u.change_cluster_status(
             cluster, c_u.CLUSTER_STATUS_VALIDATING)
-        quotas.check_cluster(cluster)
         plugin.validate(cluster)
+        quotas.check_cluster(cluster)
     except Exception as e:
         with excutils.save_and_reraise_exception():
             c_u.change_cluster_status(
@@ -162,6 +162,10 @@ def terminate_cluster(id, force=False):
 
 
 def update_cluster(id, values):
+    if "update_keypair" in values:
+        if values["update_keypair"]:
+            api.OPS.update_keypair(id)
+        values.pop("update_keypair")
     if verification_base.update_verification_required(values):
         api.OPS.handle_verification(id, values)
         return conductor.cluster_get(context.ctx(), id)
