@@ -18,7 +18,8 @@ from sahara import context
 import sahara.exceptions as ex
 from sahara.i18n import _
 import sahara.plugins.base as plugin_base
-import sahara.service.api as api
+from sahara.service import api as service_api
+from sahara.service.api import v10 as api
 from sahara.service.validations import acl
 import sahara.service.validations.base as b
 from sahara.utils import cluster as c_u
@@ -32,13 +33,16 @@ def check_cluster_scaling(data, cluster_id, **kwargs):
         raise ex.NotFoundException(
             {'id': cluster_id}, _('Object with %s not found'))
 
+    b.check_plugin_labels(
+        cluster.plugin_name, cluster.hadoop_version)
+
     acl.check_tenant_for_update(ctx, cluster)
     acl.check_protected_from_update(cluster, data)
 
     cluster_engine = cluster.sahara_info.get(
         'infrastructure_engine') if cluster.sahara_info else None
 
-    engine_type_and_version = api.OPS.get_engine_type_and_version()
+    engine_type_and_version = service_api.OPS.get_engine_type_and_version()
     if (not cluster_engine and
             not engine_type_and_version.startswith('direct')):
         raise ex.InvalidReferenceException(
@@ -67,12 +71,16 @@ def check_cluster_scaling(data, cluster_id, **kwargs):
             _("Cluster cannot be scaled not in 'Active' status. "
               "Cluster status: %s") % cluster.status)
 
+    if cluster.user_keypair_id:
+        b.check_keypair_exists(cluster.user_keypair_id)
+
+    if cluster.default_image_id:
+        b.check_image_registered(cluster.default_image_id)
+
     if data.get("resize_node_groups"):
         b.check_resize(cluster, data['resize_node_groups'])
 
     if data.get("add_node_groups"):
         b.check_add_node_groups(cluster, data['add_node_groups'])
-        b.check_network_config(data['add_node_groups'],
-                               cluster.has_proxy_gateway())
         b.check_cluster_hostnames_lengths(cluster.name,
                                           data['add_node_groups'])
