@@ -13,20 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslotest import base
 
 from sahara import context
 from sahara.db import api as db_api
 from sahara import main
+from sahara.utils import rpc
 
 
 class SaharaTestCase(base.BaseTestCase):
 
     def setUp(self):
         super(SaharaTestCase, self).setUp()
-
         self.setup_context()
+        rpc.setup('all-in-one')
 
     def setup_context(self, username="test_user", tenant_id="tenant_1",
                       auth_token="test_auth_token", tenant_name='test_tenant',
@@ -40,7 +42,7 @@ class SaharaTestCase(base.BaseTestCase):
             tenant_name=tenant_name, **kwargs))
 
     def override_config(self, name, override, group=None):
-        main.CONF.set_override(name, override, group, enforce_type=True)
+        main.CONF.set_override(name, override, group)
         self.addCleanup(main.CONF.clear_override, name, group)
 
 
