@@ -348,7 +348,7 @@ class SaharaMigrationsCheckers(object):
         desc = 'magic'
         t = db_utils.get_table(engine, 'clusters')
         engine.execute(t.insert(), id='123', name='name', plugin_name='pname',
-                       hadoop_version='1',  management_private_key='2',
+                       hadoop_version='1', management_private_key='2',
                        management_public_key='3', status_description=desc)
 
     def _check_007(self, engine, data):
@@ -626,6 +626,22 @@ class SaharaMigrationsCheckers(object):
     def _check_033(self, engine, data):
         self.assertColumnExists(engine, 'clusters', 'anti_affinity_ratio')
 
+    def _check_034(self, engine, data):
+        self.assertColumnExists(engine, 'node_groups',
+                                'boot_from_volume')
+        self.assertColumnExists(engine, 'node_group_templates',
+                                'boot_from_volume')
+        self.assertColumnExists(engine, 'templates_relations',
+                                'boot_from_volume')
+
+    def _check_035(self, engine, data):
+        for col in ['boot_volume_type',
+                    'boot_volume_availability_zone',
+                    'boot_volume_local_to_instance']:
+            self.assertColumnExists(engine, 'node_groups', col)
+            self.assertColumnExists(engine, 'node_group_templates', col)
+            self.assertColumnExists(engine, 'templates_relations', col)
+
 
 class TestMigrationsMySQL(SaharaMigrationsCheckers,
                           base.BaseWalkMigrationTestCase,
