@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
 
-import mock
+from unittest import mock
+
+from oslo_utils import uuidutils
 
 from sahara import conductor
 from sahara import context
@@ -26,12 +27,12 @@ from sahara.utils import cluster_progress_ops as cpo
 
 class FakeInstance(object):
     def __init__(self):
-        self.id = uuid.uuid4()
-        self.name = uuid.uuid4()
-        self.cluster_id = uuid.uuid4()
-        self.node_group_id = uuid.uuid4()
-        self.instance_id = uuid.uuid4()
-        self.instance_name = uuid.uuid4()
+        self.id = uuidutils.generate_uuid()
+        self.name = uuidutils.generate_uuid()
+        self.cluster_id = uuidutils.generate_uuid()
+        self.node_group_id = uuidutils.generate_uuid()
+        self.instance_id = uuidutils.generate_uuid()
+        self.instance_name = uuidutils.generate_uuid()
 
 
 class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
@@ -78,7 +79,7 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
         result_cluster = self.api.cluster_get(ctx, cluster.id)
         result_step = result_cluster.provision_progress[0]
 
-        self.assertEqual(True, result_step.successful)
+        self.assertTrue(result_step.successful)
 
         # check updating in case of failed provision step
 
@@ -98,7 +99,7 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
 
         for step in result_cluster.provision_progress:
             if step.id == step_id2:
-                self.assertEqual(False, step.successful)
+                self.assertFalse(step.successful)
 
         # check that it's possible to add provision step after failed step
         step_id3 = cpo.add_provisioning_step(cluster.id, "some_name", 2)
