@@ -152,9 +152,9 @@ def _cleanup():
 
 
 def _read_paramimko_stream(recv_func):
-    result = ''
+    result = b''
     buf = recv_func(1024)
-    while buf != '':
+    while buf != b'':
         result += buf
         buf = recv_func(1024)
 
@@ -182,6 +182,12 @@ def _execute_command(cmd, run_as_root=False, get_stderr=False,
     stdout = _read_paramimko_stream(chan.recv)
     stderr = _read_paramimko_stream(chan.recv_stderr)
 
+    if type(stdout) == bytes:
+        stdout = stdout.decode('utf-8')
+
+    if type(stderr) == bytes:
+        stderr = stderr.decode('utf-8')
+
     ret_code = chan.recv_exit_status()
 
     if ret_code and raise_when_error:
@@ -270,7 +276,11 @@ def _get_http_client(host, port, proxy_command=None, gateway_host=None,
 
 
 def _write_fl(sftp, remote_file, data):
-    write_data = paramiko.py3compat.StringIO(data)
+    try:
+        write_data = paramiko.py3compat.StringIO(data)
+    except TypeError:
+        write_data = paramiko.py3compat.BytesIO(data)
+
     sftp.putfo(write_data, remote_file)
 
 
@@ -301,6 +311,19 @@ def _append_file(sftp, remote_file, data, run_as_root):
         _append_fl(sftp, remote_file, data)
 
 
+def _prepend_file(sftp, remote_file, data, run_as_root):
+    if run_as_root:
+        temp_file = 'temp-file-%s' % uuidutils.generate_uuid()
+        temp_remote_file = 'temp-remote-file-%s' % uuidutils.generate_uuid()
+        _write_fl(sftp, temp_file, data)
+        _execute_command(
+            'cat %s > %s' % (remote_file, temp_remote_file))
+        _execute_command(
+            'cat %s %s > %s' % (
+                temp_file, temp_remote_file, remote_file), run_as_root=True)
+        _execute_command('rm -f %s %s' % (temp_file, temp_remote_file))
+
+
 def _write_file_to(remote_file, data, run_as_root=False):
     global _ssh
 
@@ -331,11 +354,29 @@ def _append_to_files(files, run_as_root=False):
         _append_file(sftp, fl, data, run_as_root)
 
 
+def _prepend_to_file(remote_file, data, run_as_root=False):
+    global _ssh
+
+    _prepend_file(_ssh.open_sftp(), remote_file, data, run_as_root)
+
+
+def _prepend_to_files(files, run_as_root=False):
+    global _ssh
+
+    sftp = _ssh.open_sftp()
+
+    for fl, data in six.iteritems(files):
+        _prepend_file(sftp, fl, data, run_as_root)
+
+
 def _read_file(sftp, remote_file):
     fl = sftp.file(remote_file, 'r')
     data = fl.read()
     fl.close()
-    return data
+    try:
+        return data.decode('utf-8')
+    except Exception:
+        return data
 
 
 def _read_file_from(remote_file, run_as_root=False):
@@ -878,6 +919,12 @@ class InstanceInteropHelper(remote.Remote):
         self._log_command(description)
         self._run_s(_append_to_files, timeout, description, files, run_as_root)
 
+    def prepend_to_file(self, r_file, data, run_as_root=False, timeout=None):
+        description = _('Prepending to file "%s"') % r_file
+        self._log_command(description)
+        self._run_s(_prepend_to_file, timeout, description,
+                    r_file, data, run_as_root)
+
     def read_file_from(self, remote_file, run_as_root=False, timeout=None):
         description = _('Reading file "%s"') % remote_file
         self._log_command(description)
@@ -919,7 +966,7 @@ class InstanceInteropHelper(remote.Remote):
                             old_line_with_start_string,
                             new_line, timeout=None):
         description = _('In file "%(file)s" replacing line'
-                        ' begining with string'
+                        ' begining with string '
                         '"%(old_line_with_start_string)s"'
                         ' with "%(new_line)s"') % {
             "file": remote_file,
